git.lucas.co / cce-compositor
Wayland compositor (wlroots)
git clone https://git.lucas.co/cce-compositor.git

commit72670d464e3e33cdc44cd46549082d43cfff5a41
parente09fca562c
authorLucas Galante <[email protected]>
date2026-06-09 10:09
Refactor and adapt widgets to use UiContext and scale factor

 Cargo.lock    | 30 +++++++++++++++---------------
 Cargo.toml    |  2 +-
 Makefile      |  2 +-
 start-rust.sh | 31 +++++++++++++++----------------
 4 files changed, 32 insertions(+), 33 deletions(-)

diff --git a/Cargo.lock b/Cargo.lock
index 44c8104..a0b1734 100644
--- a/Cargo.lock
+++ b/Cargo.lock
@@ -100,6 +100,21 @@ dependencies = [
  "shlex",
 ]
 
+[[package]]
+name = "cce-server"
+version = "0.1.0"
+dependencies = [
+ "bindgen",
+ "bitflags",
+ "cc",
+ "clap",
+ "env_logger",
+ "libc",
+ "log",
+ "nix",
+ "pkg-config",
+]
+
 [[package]]
 name = "cexpr"
 version = "0.6.0"
@@ -172,21 +187,6 @@ version = "1.1.0"
 source = "registry+https://github.com/rust-lang/crates.io-index"
 checksum = "c8d4a3bb8b1e0c1050499d1815f5ab16d04f0959b233085fb31653fbfc9d98f9"
 
-[[package]]
-name = "clear-computing-environment-server"
-version = "0.1.0"
-dependencies = [
- "bindgen",
- "bitflags",
- "cc",
- "clap",
- "env_logger",
- "libc",
- "log",
- "nix",
- "pkg-config",
-]
-
 [[package]]
 name = "colorchoice"
 version = "1.0.5"
diff --git a/Cargo.toml b/Cargo.toml
index 65d220a..63fc739 100644
--- a/Cargo.toml
+++ b/Cargo.toml
@@ -1,5 +1,5 @@
 [package]
-name = "clear-computing-environment-server"
+name = "cce-server"
 version = "0.1.0"
 edition = "2021"
 
diff --git a/Makefile b/Makefile
index 88ebfc3..b5b1ede 100644
--- a/Makefile
+++ b/Makefile
@@ -5,7 +5,7 @@ build:
 
 install: build
 	mkdir -p ~/.local/bin
-	install -m 755 target/release/clear-computing-environment-server ~/.local/bin/clear-computing-environment-server
+	install -m 755 target/release/cce-server ~/.local/bin/cce-server
 
 run:
 	cargo run
diff --git a/start-rust.sh b/start-rust.sh
index 23c4ff3..398ee3a 100755
--- a/start-rust.sh
+++ b/start-rust.sh
@@ -1,7 +1,7 @@
 #!/bin/sh
-# Launch clear-computing-environment-server with ccec
+# Launch cce-server with cce-client
 # Usage: ./start-rust.sh [--logging] [--debug]
-
+ 
 LOGGING=false
 DEBUG=false
 for arg in "$@"; do
@@ -10,37 +10,36 @@ for arg in "$@"; do
         --debug) DEBUG=true ;;
     esac
 done
-
+ 
 export XDG_RUNTIME_DIR=/run/user/$(id -u)
 export XCURSOR_THEME="crosshair-theme"
 export XCURSOR_SIZE=24
 export XCURSOR_PATH="/home/lsgalante/.local/share/icons:/home/lsgalante/.icons:/usr/share/icons"
 export WLR_NO_HARDWARE_CURSORS=1
-
-# Create the ccec launch script
+ 
+# Create the cce-client launch script
 DEBUG_FLAG=""
 if [ "$DEBUG" = true ]; then
     DEBUG_FLAG="WAYLAND_DEBUG=1 "
 fi
-
-cat > /tmp/ccec-launch-rust.sh << LAUNCH_EOF
+ 
+cat > /tmp/cce-client-launch-rust.sh << LAUNCH_EOF
 #!/bin/sh
-${DEBUG_FLAG}exec /home/lsgalante/.local/bin/ccec 2>/tmp/ccec-\${WAYLAND_DISPLAY}.log
+${DEBUG_FLAG}exec /home/lsgalante/.local/bin/cce-client 2>/tmp/cce-client-\${WAYLAND_DISPLAY}.log
 LAUNCH_EOF
-chmod +x /tmp/ccec-launch-rust.sh
-
+chmod +x /tmp/cce-client-launch-rust.sh
+ 
 if [ "$LOGGING" = true ] || [ "$DEBUG" = true ]; then
-    echo "Starting clear-computing-environment-server with ccec..."
-    echo "  Logs: /tmp/river-ccec.log + /tmp/ccec-\${WAYLAND_DISPLAY}.log"
+    echo "Starting cce-server with cce-client..."
+    echo "  Logs: /tmp/river-cce-client.log + /tmp/cce-client-\${WAYLAND_DISPLAY}.log"
     if [ "$DEBUG" = true ]; then
         echo "  Wayland debug logging enabled (WAYLAND_DEBUG=1)"
     fi
 fi
-
-# Resolve script directory to reference target/release/clear-computing-environment-server reliably
+ 
+# Resolve script directory to reference target/release/cce-server reliably
 SCRIPT_DIR="$(cd "$(dirname "$0")" && pwd)"
 if [ "$DEBUG" = true ]; then
     export WAYLAND_DEBUG=1
 fi
-exec "$SCRIPT_DIR/target/release/clear-computing-environment-server" -c /tmp/ccec-launch-rust.sh 2>/tmp/river-ccec.log
-
+exec "$SCRIPT_DIR/target/release/cce-server" -c /tmp/cce-client-launch-rust.sh 2>/tmp/river-cce-client.log